@@ -12,7 +12,6 @@ impl<T> Coerce for T
 where
     T: ?Sized,
 {
-    #[inline(always)]
     unsafe fn coerce_ref<U>(&self, metadata: Metadata<U>) -> &U
     where
         U: ?Sized,
@@ -21,8 +20,6 @@ where
         let ptr = ptr::from_raw_parts(data_address, metadata);
         &*ptr
     }
-
-    #[inline(always)]
     unsafe fn coerce_mut<U>(&mut self, metadata: Metadata<U>) -> &mut U
     where
         U: ?Sized,
@@ -37,14 +34,14 @@ coercible_trait!(Any);
 
 coercibles! {
     <'a, T, U>(self) {
-        &T => &'a T::Coerced<'a, U>,
-        &mut T => &'a T::Coerced<'a, U>,
-        RefCell<T> => RefCell<T::Coerced<'a, U>> { self.borrow().innermost_type_id() },
-        Ref<'_, T> => Ref<'a, T::Coerced<'a, U>>,
-        RefMut<'_, T> => RefMut<'a, T::Coerced<'a, U>>,
-        #["alloc"] Box<T> => Box<T::Coerced<'a, U>>,
-        #["alloc"] Rc<T> => Rc<T::Coerced<'a, U>>,
-        #["alloc"] Arc<T> => Arc<T::Coerced<'a, U>>,
+        &T => &'a T::Coerced<U>,
+        &mut T => &'a mut T::Coerced<U>,
+        RefCell<T> => RefCell<T::Coerced<U>> { self.borrow().innermost_type_id() },
+        Ref<'_, T> => Ref<'a, T::Coerced<U>>,
+        RefMut<'_, T> => RefMut<'a, T::Coerced<U>>,
+        #["alloc"] Box<T> => Box<T::Coerced<U>>,
+        #["alloc"] Rc<T> => Rc<T::Coerced<U>>,
+        #["alloc"] Arc<T> => Arc<T::Coerced<U>>,
     }
 }
 
