@@ -14,7 +14,11 @@ pub type Metadata<U> = <U as ptr::Pointee>::Metadata;
 /// A type that inherits [`Pointee::Metadata`][ptr::Pointee::Metadata]
 /// from a contained type, and whose pointers are therefore coercible if that
 /// contained type is coercible.
-pub unsafe trait Coercible {
+///
+/// # Safety
+/// The safety of unsafe code in rattish depends upon this trait being correctly
+/// implemented.
+pub unsafe trait Coercible<'a> {
     /// The type that `Self` will become if the contained type is coerced to
     /// `U`.
     ///
@@ -22,24 +26,35 @@ pub unsafe trait Coercible {
     /// presently rendered by Rustdoc.  Its full declaration is:
     ///
     /// ```ignore
-    /// type Coerced<U: ?Sized>: ?Sized
+    /// type Coerced<U: ?Sized>: 'a + ?Sized
     /// ```
-    type Coerced<'a, U: 'a + ?Sized>: 'a + ?Sized;
+    ///
+    /// For example: `&mut T` becomes `&mut U`, `Box<T>` becomes `Box<U>`, etc.
+    /// A `dyn Trait` will generally just become `U`.
+    type Coerced<U: 'a + ?Sized>: 'a + ?Sized;
 
     /// The ultimate type whose
     /// [`Pointee::Metadata`][ptr::Pointee::Metadata] is that of `Self`.  For
     /// example, if `Self::Metadata` is [`DynMetadata<T>`][ptr::DynMetadata],
     /// then `Innermost` will be `T`.
+    ///
+    /// Unless `Self` is a leaf, such as a `dyn Trait` (in which case this is
+    /// just `Self`), this should just delegate to the contained type's
+    /// `Innermost`.
     type Innermost: ?Sized;
 
     /// Returns the [`TypeId`] of the *concrete* value underlying
     /// [`Innermost`][Coercible::Innermost].
+    ///
+    /// Unless `Self` is a leaf, such as a `dyn Trait` (in which case this
+    /// should delegate to a trait method), this should just delegate to the
+    /// contained type's `innermost_type_id`.
     fn innermost_type_id(&self) -> TypeId;
 }
 
 /// The type that `X` will become if its contained type is coerced to `Y`.
 #[allow(type_alias_bounds)]
-pub type Coerced<'a, X: Coercible, Y> = X::Coerced<'a, Y>;
+pub type Coerced<'a, X: Coercible<'a>, Y> = X::Coerced<Y>;
 
 /// Reference coercion.
 pub trait Coerce {
@@ -63,19 +78,15 @@ pub trait Coerce {
 /// A pointer-type to a [`Coercible`].
 pub trait Pointer<'a>
 where
-    Self: Coercible + Deref + Sized,
-    Self::Target: Coercible,
+    Self: Coercible<'a> + Deref + Sized,
+    Self::Target: Coercible<'a>,
 {
     /// Perform the coercion.
     ///
     /// # Safety
     /// `metadata` must be correct for `Self::Target`.
-    unsafe fn coerce<U>(
-        self,
-        metadata: Metadata<Coerced<'a, Self::Target, U>>,
-    ) -> Self::Coerced<'a, U>
+    unsafe fn coerce<U>(self, metadata: Metadata<Coerced<'a, Self::Target, U>>) -> Self::Coerced<U>
     where
         U: ?Sized,
-        Self::Coerced<'a, U>: Sized;
-    // Coerced<'a, Self::Innermost, U>: ptr::Pointee<Metadata = Metadata<U>>;
+        Self::Coerced<U>: Sized;
 }
